avdevice

package
v0.0.0-...-3ef2c16 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2015 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Use of this source code is governed by a MIT license that can be found in the LICENSE file. by Giorgis (habtom@giorgis.io)

The input and output devices provided by the libavdevice library The libavdevice library provides the same interface as libavformat. Namely, an input device is considered like a demuxer, and an output device like a muxer, and the interface and generic device options are the same provided by libavformat

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Avdevice_app_to_dev_control_message

func Avdevice_app_to_dev_control_message(s *AVFormatContext, m AVAppToDevMessageType, da int, d uintptr) int

int avdevice_app_to_dev_control_message (struct AVFormatContext *s, enum AVAppToDevMessageType type, void *data, size_t data_size) Send control message from application to device.

func Avdevice_capabilities_create

func Avdevice_capabilities_create(c **AVDeviceCapabilitiesQuery, s *AVFormatContext, d **AVDictionary) int

int avdevice_capabilities_create (AVDeviceCapabilitiesQuery **caps, AVFormatContext *s, AVDictionary **device_options) Initialize capabilities probing API based on AVOption API.

func Avdevice_capabilities_free

func Avdevice_capabilities_free(c **AVDeviceCapabilitiesQuery, s *AVFormatContext)

void avdevice_capabilities_free (AVDeviceCapabilitiesQuery **caps, AVFormatContext *s) Free resources created by avdevice_capabilities_create()

func Avdevice_configuration

func Avdevice_configuration() string

const char * avdevice_configuration (void) Return the libavdevice build-time configuration.

func Avdevice_dev_to_app_control_message

func Avdevice_dev_to_app_control_message(fcxt *AVFormatContext, m AVDevToAppMessageType, da int, d uintptr) int

int avdevice_dev_to_app_control_message (struct AVFormatContext *s, enum AVDevToAppMessageType type, void *data, size_t data_size) Send control message from device to application.

func Avdevice_free_list_devices

func Avdevice_free_list_devices(d **AVDeviceInfoList)

void avdevice_free_list_devices (AVDeviceInfoList **device_list) Convenient function to free result of avdevice_list_devices().

func Avdevice_license

func Avdevice_license() string

const char * avdevice_license (void) Return the libavdevice license.

func Avdevice_list_devices

func Avdevice_list_devices(s *AVFormatContext, d **AVDeviceInfoList) int

int avdevice_list_devices (struct AVFormatContext *s, AVDeviceInfoList **device_list) List devices.

func Avdevice_list_input_sources

func Avdevice_list_input_sources(d *AVInputFormat, dv string, do *AVDictionary, dl **AVDeviceInfoList) int

int avdevice_list_input_sources (struct AVInputFormat *device, const char *device_name, AVDictionary *device_options, AVDeviceInfoList **device_list) List devices.

func Avdevice_list_output_sinks

func Avdevice_list_output_sinks(d *AVOutputFormat, dn string, di *AVDictionary, dl **AVDeviceInfoList) int

int avdevice_list_output_sinks (struct AVOutputFormat *device, const char *device_name, AVDictionary *device_options, AVDeviceInfoList **device_list)

func Avdevice_register_all

func Avdevice_register_all()

void avdevice_register_all (void) Initialize libavdevice and register all the input and output devices.

func Avdevice_version

func Avdevice_version() uint

unsigned avdevice_version (void) Return the LIBAVDEVICE_VERSION_INT constant.

Types

type AVAppToDevMessageType

type AVAppToDevMessageType C.enum_AVAppToDevMessageType

type AVDevToAppMessageType

type AVDevToAppMessageType C.enum_AVDevToAppMessageType

type AVDeviceCapabilitiesQuery

type AVDeviceCapabilitiesQuery C.struct_AVDeviceCapabilitiesQuery

type AVDeviceInfo

type AVDeviceInfo C.struct_AVDeviceInfo

type AVDeviceInfoList

type AVDeviceInfoList C.struct_AVDeviceInfoList

type AVDeviceRect

type AVDeviceRect C.struct_AVDeviceRect

type AVDictionary

type AVDictionary C.struct_AVDictionary

type AVFormatContext

type AVFormatContext C.struct_AVFormatContext

type AVInputFormat

type AVInputFormat C.struct_AVInputFormat

func Av_input_audio_device_next

func Av_input_audio_device_next(d *AVInputFormat) *AVInputFormat

AVInputFormat * av_input_audio_device_next (AVInputFormat *d) Audio input devices iterator.

func Av_input_video_device_next

func Av_input_video_device_next(d *AVInputFormat) *AVInputFormat

AVInputFormat * av_input_video_device_next (AVInputFormat *d) Video input devices iterator.

type AVOutputFormat

type AVOutputFormat C.struct_AVOutputFormat

func Av_output_audio_device_next

func Av_output_audio_device_next(d *AVOutputFormat) *AVOutputFormat

AVOutputFormat * av_output_audio_device_next (AVOutputFormat *d) Audio output devices iterator.

func Av_output_video_device_next

func Av_output_video_device_next(d *AVOutputFormat) *AVOutputFormat

AVOutputFormat * av_output_video_device_next (AVOutputFormat *d) Video output devices iterator.

Jump to