Documentation
¶
Overview ¶
Use of this source code is governed by a MIT license that can be found in the LICENSE file. by Giorgis (habtom@giorgis.io)
Some generic features and utilities provided by the libavutil library The libavutil library is a utility library to aid portable multimedia programming. It contains safe portable string functions, random number generators, data structures, additional mathematics functions, cryptography and multimedia related functionality
Use of this source code is governed by a MIT license that can be found in the LICENSE file. by Giorgis (habtom@giorgis.io)
Use of this source code is governed by a MIT license that can be found in the LICENSE file. by Giorgis (habtom@giorgis.io)
Use of this source code is governed by a MIT license that can be found in the LICENSE file. by Giorgis (habtom@giorgis.io)
Index ¶
- func Av_calloc(n, s uintptr) unsafe.Pointer
- func Av_dynarray2_add(t *unsafe.Pointer, n *int, e uintptr, d uint8) unsafe.Pointer
- func Av_dynarray_add(t unsafe.Pointer, n *int, e unsafe.Pointer)
- func Av_dynarray_add_nofree(p unsafe.Pointer, n *int, e unsafe.Pointer) int
- func Av_fast_malloc(p unsafe.Pointer, s *uint, m uintptr)
- func Av_fast_realloc(p unsafe.Pointer, s *uint, m uintptr) unsafe.Pointer
- func Av_frame_copy_props(d, s *AVFrame) int
- func Av_frame_free(f *AVFrame)
- func Av_frame_get_buffer(f *AVFrame, a int) int
- func Av_frame_get_qp_table(f *AVFrame, s, t *int) int8
- func Av_frame_is_writable(f *AVFrame) int
- func Av_frame_make_writable(f *AVFrame) int
- func Av_frame_move_ref(d, s *AVFrame)
- func Av_frame_ref(d, s *AVFrame) int
- func Av_frame_set_qp_table(f *AVFrame, b *AVBufferRef, s, q int) int
- func Av_frame_unref(f *AVFrame)
- func Av_free(p unsafe.Pointer)
- func Av_freep(p unsafe.Pointer)
- func Av_get_media_type_string(mt AVMediaType) string
- func Av_get_picture_type_char(pt AVPictureType) string
- func Av_int_list_length_for_size(e uint, l int, t uint64) uint
- func Av_malloc(s uintptr) unsafe.Pointer
- func Av_malloc_array(n, s uintptr) unsafe.Pointer
- func Av_mallocz(s uintptr) unsafe.Pointer
- func Av_mallocz_array(n, s uintptr) unsafe.Pointer
- func Av_max_alloc(m uintptr)
- func Av_memcpy_backptr(d *uintptr, b, c int)
- func Av_memdup(p *int, s uintptr) unsafe.Pointer
- func Av_realloc(p *int, s uintptr) unsafe.Pointer
- func Av_realloc_array(p int, n, s uintptr) unsafe.Pointer
- func Av_realloc_f(p int, n, e uintptr) unsafe.Pointer
- func Av_reallocp(p int, s uintptr) int
- func Av_reallocp_array(p int, n, s uintptr) int
- func Av_size_mult(a, b uintptr, r *uintptr) int
- func Av_strdup(s string) string
- func Av_strndup(s string, l uintptr) string
- func Av_x_if_null(p, x int)
- func AvutilVersion() uint
- func Avutil_configuration() string
- func Avutil_license() string
- func Data(f *AVFrame) *uint8
- func Linesize(f *AVFrame) int
- type AVBuffer
- type AVBufferPool
- type AVBufferRef
- type AVDictionary
- type AVFrame
- type AVFrameSideData
- type AVFrameSideDataType
- type AVMediaType
- type AVOptions
- type AVPictureType
- type AVRational
- type AVTree
- type File
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Av_calloc ¶
void * av_calloc (size_t nmemb, size_t size) av_malloc_attrib Allocate a block of nmemb * size bytes with alignment suitable for all memory accesses (including vectors if available on the CPU) and zero all the bytes of the block.
func Av_dynarray2_add ¶
void * av_dynarray2_add (void **tab_ptr, int *nb_ptr, size_t elem_size, const uint8_t *elem_data) Add an element of size elem_size to a dynamic array.
func Av_dynarray_add ¶
void av_dynarray_add (void *tab_ptr, int *nb_ptr, void *elem) Add an element to a dynamic array.
func Av_dynarray_add_nofree ¶
int av_dynarray_add_nofree (void *tab_ptr, int *nb_ptr, void *elem) Add an element to a dynamic array.
func Av_fast_malloc ¶
void av_fast_malloc (void *ptr, unsigned int *size, size_t min_size) Allocate a buffer, reusing the given one if large enough.
func Av_fast_realloc ¶
void * av_fast_realloc (void *ptr, unsigned int *size, size_t min_size) Reallocate the given block if it is not large enough, otherwise do nothing.
func Av_frame_copy_props ¶
int av_frame_copy_props (AVFrame *dst, const AVFrame *src) Copy only "metadata" fields from src to dst.
func Av_frame_free ¶
func Av_frame_free(f *AVFrame)
void av_frame_free (AVFrame **frame) Free the frame and any dynamically allocated objects in it, e.g.
func Av_frame_get_buffer ¶
int av_frame_get_buffer (AVFrame *frame, int align) Allocate new buffer(s) for audio or video data.
func Av_frame_get_qp_table ¶
int8_t * av_frame_get_qp_table (AVFrame *f, int *stride, int *type)
func Av_frame_is_writable ¶
int av_frame_is_writable (AVFrame *frame) Check if the frame data is writable.
func Av_frame_make_writable ¶
int av_frame_make_writable (AVFrame *frame) Ensure that the frame data is writable, avoiding data copy if possible.
func Av_frame_move_ref ¶
func Av_frame_move_ref(d, s *AVFrame)
void av_frame_move_ref (AVFrame *dst, AVFrame *src) Move everythnig contained in src to dst and reset src.
func Av_frame_ref ¶
int av_frame_ref (AVFrame *dst, AVFrame *src) Setup a new reference to the data described by an given frame.
func Av_frame_set_qp_table ¶
func Av_frame_set_qp_table(f *AVFrame, b *AVBufferRef, s, q int) int
int av_frame_set_qp_table (AVFrame *f, AVBufferRef *buf, int stride, int qp_type)
func Av_frame_unref ¶
func Av_frame_unref(f *AVFrame)
void av_frame_unref (AVFrame *frame) Unreference all the buffers referenced by frame and reset the frame fields.
func Av_free ¶
void av_free (void *ptr) Free a memory block which has been allocated with av_malloc(z)() or av_realloc().
func Av_freep ¶
void av_freep (void *ptr) Free a memory block which has been allocated with av_malloc(z)() or av_realloc() and set the pointer pointing to it to NULL.
func Av_get_media_type_string ¶
func Av_get_media_type_string(mt AVMediaType) string
const char * av_get_media_type_string (enum AVMediaType media_type) Return a string describing the media_type enum, NULL if media_type is unknown.
func Av_get_picture_type_char ¶
func Av_get_picture_type_char(pt AVPictureType) string
char av_get_picture_type_char (enum AVPictureType pict_type) Return a single letter to describe the given picture type pict_type.
func Av_int_list_length_for_size ¶
unsigned av_int_list_length_for_size (unsigned elsize, const void *list, uint64_t term) av_pure Compute the length of an integer list.
func Av_malloc ¶
void * av_malloc (size_t size) av_malloc_attrib 1(1) Allocate a block of size bytes with alignment suitable for all memory accesses (including vectors if available on the CPU).
func Av_malloc_array ¶
static void * av_malloc_array (size_t nmemb, size_t size)
func Av_mallocz ¶
void * av_mallocz (size_t size) av_malloc_attrib 1(1) Allocate a block of size bytes with alignment suitable for all memory accesses (including vectors if available on the CPU) and zero all the bytes of the block.
func Av_mallocz_array ¶
static void * av_mallocz_array (size_t nmemb, size_t size)
func Av_max_alloc ¶
func Av_max_alloc(m uintptr)
void av_max_alloc (size_t max) Set the maximum size that may me allocated in one block.
func Av_memcpy_backptr ¶
void av_memcpy_backptr (uint8_t *dst, int back, int cnt) deliberately overlapping memcpy implementation
func Av_realloc ¶
void * av_realloc (void *ptr, size_t size) 1(2) Allocate or reallocate a block of memory.
func Av_realloc_array ¶
void * av_realloc_array (void *ptr, size_t nmemb, size_t size)
func Av_realloc_f ¶
void * av_realloc_f (void *ptr, size_t nelem, size_t elsize) Allocate or reallocate a block of memory.
func Av_reallocp ¶
int av_reallocp (void *ptr, size_t size) Allocate or reallocate a block of memory.
func Av_reallocp_array ¶
int av_reallocp_array (void *ptr, size_t nmemb, size_t size)
func Av_size_mult ¶
static int av_size_mult (size_t a, size_t b, size_t *r) Multiply two size_t values checking for overflow.
func Av_strndup ¶
char * av_strndup (const char *s, size_t len) av_malloc_attrib Duplicate a substring of the string s.
func Av_x_if_null ¶
func Av_x_if_null(p, x int)
static void * av_x_if_null (const void *p, const void *x) Return x default pointer in case p is NULL.
func AvutilVersion ¶
func AvutilVersion() uint
unsigned avutil_version (void) Return the LIBAVUTIL_VERSION_INT constant.
func Avutil_configuration ¶
func Avutil_configuration() string
const char * avutil_configuration (void) Return the libavutil build-time configuration.
func Avutil_license ¶
func Avutil_license() string
const char * avutil_license (void) Return the libavutil license.
Types ¶
type AVBuffer ¶
type AVBuffer C.struct_AVBuffer
type AVBufferPool ¶
type AVBufferPool C.struct_AVBufferPool
type AVBufferRef ¶
type AVBufferRef C.struct_AVBufferRef
func Av_frame_get_plane_buffer ¶
func Av_frame_get_plane_buffer(f *AVFrame, p int) *AVBufferRef
AVBufferRef * av_frame_get_plane_buffer (AVFrame *frame, int plane) Get the buffer reference a given data plane is stored in.
type AVDictionary ¶
type AVDictionary C.struct_AVDictionary
func Avpriv_frame_get_metadatap ¶
func Avpriv_frame_get_metadatap(f *AVFrame) **AVDictionary
AVDictionary ** avpriv_frame_get_metadatap (AVFrame *frame)
type AVFrame ¶
type AVFrame C.struct_AVFrame
func Av_frame_alloc ¶
func Av_frame_alloc() *AVFrame
AVFrame * av_frame_alloc (void) Allocate an AVFrame and set its fields to default values.
func Av_frame_clone ¶
AVFrame * av_frame_clone (AVFrame *src) Create a new frame that references the same data as src.
type AVFrameSideData ¶
type AVFrameSideData C.struct_AVFrameSideData
func Av_frame_get_side_data ¶
func Av_frame_get_side_data(f *AVFrame, t AVFrameSideDataType) *AVFrameSideData
AVFrameSideData * av_frame_get_side_data (AVFrame *frame, enum AVFrameSideDataType type)
func Av_frame_new_side_data ¶
func Av_frame_new_side_data(f *AVFrame, d AVFrameSideDataType, s int) *AVFrameSideData
AVFrameSideData * av_frame_new_side_data (AVFrame *frame, enum AVFrameSideDataType type, int size) Add a new side data to a frame.
type AVFrameSideDataType ¶
type AVFrameSideDataType C.enum_AVFrameSideDataType
type AVMediaType ¶
type AVMediaType C.enum_AVMediaType
type AVOptions ¶
type AVOptions C.struct_AVOptions
type AVPictureType ¶
type AVPictureType C.enum_AVPictureType
type AVRational ¶
type AVRational C.struct_AVRational
func Av_get_time_base_q ¶
func Av_get_time_base_q() AVRational
AVRational av_get_time_base_q (void) Return the fractional representation of the internal time base.
type AVTree ¶
type AVTree C.struct_AVTree